"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAccountInfo = exports.getAddressStringToBytes = exports.getAddressBytesToString = exports.getBech32Prefix = exports.getModuleAccountByName = exports.getModuleAccounts = exports.getParams = exports.getAccountAddressByID = exports.getAccount = exports.getAccounts = void 0;
const helper_func_types_1 = require("../../../helper-func-types");
const query_1 = require("./query");
/**
 * Accounts returns all the existing accounts.
 *
 * When called from another module, this query might consume a high amount of
 * gas if the pagination field is incorrectly set.
 * @name getAccounts
 * @package cosmos.auth.v1beta1
 * @see proto service: cosmos.auth.v1beta1.Accounts
 */
exports.getAccounts = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryAccountsRequest.encode,
    decode: query_1.QueryAccountsResponse.decode,
    service: "cosmos.auth.v1beta1.Query",
    method: "Accounts"
});
/**
 * Account returns account details based on address.
 * @name getAccount
 * @package cosmos.auth.v1beta1
 * @see proto service: cosmos.auth.v1beta1.Account
 */
exports.getAccount = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryAccountRequest.encode,
    decode: query_1.QueryAccountResponse.decode,
    service: "cosmos.auth.v1beta1.Query",
    method: "Account"
});
/**
 * AccountAddressByID returns account address based on account number.
 * @name getAccountAddressByID
 * @package cosmos.auth.v1beta1
 * @see proto service: cosmos.auth.v1beta1.AccountAddressByID
 */
exports.getAccountAddressByID = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryAccountAddressByIDRequest.encode,
    decode: query_1.QueryAccountAddressByIDResponse.decode,
    service: "cosmos.auth.v1beta1.Query",
    method: "AccountAddressByID"
});
/**
 * Params queries all parameters.
 * @name getParams
 * @package cosmos.auth.v1beta1
 * @see proto service: cosmos.auth.v1beta1.Params
 */
exports.getParams = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryParamsRequest.encode,
    decode: query_1.QueryParamsResponse.decode,
    service: "cosmos.auth.v1beta1.Query",
    method: "Params"
});
/**
 * ModuleAccounts returns all the existing module accounts.
 * @name getModuleAccounts
 * @package cosmos.auth.v1beta1
 * @see proto service: cosmos.auth.v1beta1.ModuleAccounts
 */
exports.getModuleAccounts = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryModuleAccountsRequest.encode,
    decode: query_1.QueryModuleAccountsResponse.decode,
    service: "cosmos.auth.v1beta1.Query",
    method: "ModuleAccounts"
});
/**
 * ModuleAccountByName returns the module account info by module name
 * @name getModuleAccountByName
 * @package cosmos.auth.v1beta1
 * @see proto service: cosmos.auth.v1beta1.ModuleAccountByName
 */
exports.getModuleAccountByName = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryModuleAccountByNameRequest.encode,
    decode: query_1.QueryModuleAccountByNameResponse.decode,
    service: "cosmos.auth.v1beta1.Query",
    method: "ModuleAccountByName"
});
/**
 * Bech32Prefix queries bech32Prefix
 * @name getBech32Prefix
 * @package cosmos.auth.v1beta1
 * @see proto service: cosmos.auth.v1beta1.Bech32Prefix
 */
exports.getBech32Prefix = (0, helper_func_types_1.buildQuery)({
    encode: query_1.Bech32PrefixRequest.encode,
    decode: query_1.Bech32PrefixResponse.decode,
    service: "cosmos.auth.v1beta1.Query",
    method: "Bech32Prefix"
});
/**
 * AddressBytesToString converts Account Address bytes to string
 * @name getAddressBytesToString
 * @package cosmos.auth.v1beta1
 * @see proto service: cosmos.auth.v1beta1.AddressBytesToString
 */
exports.getAddressBytesToString = (0, helper_func_types_1.buildQuery)({
    encode: query_1.AddressBytesToStringRequest.encode,
    decode: query_1.AddressBytesToStringResponse.decode,
    service: "cosmos.auth.v1beta1.Query",
    method: "AddressBytesToString"
});
/**
 * AddressStringToBytes converts Address string to bytes
 * @name getAddressStringToBytes
 * @package cosmos.auth.v1beta1
 * @see proto service: cosmos.auth.v1beta1.AddressStringToBytes
 */
exports.getAddressStringToBytes = (0, helper_func_types_1.buildQuery)({
    encode: query_1.AddressStringToBytesRequest.encode,
    decode: query_1.AddressStringToBytesResponse.decode,
    service: "cosmos.auth.v1beta1.Query",
    method: "AddressStringToBytes"
});
/**
 * AccountInfo queries account info which is common to all account types.
 * @name getAccountInfo
 * @package cosmos.auth.v1beta1
 * @see proto service: cosmos.auth.v1beta1.AccountInfo
 */
exports.getAccountInfo = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryAccountInfoRequest.encode,
    decode: query_1.QueryAccountInfoResponse.decode,
    service: "cosmos.auth.v1beta1.Query",
    method: "AccountInfo"
});
