import { Any } from "../../../../google/protobuf/any";
import { Event } from "../../../../tendermint/abci/types";
import { Block } from "../../../../tendermint/types/block";
import { BinaryReader, BinaryWriter } from "../../../../binary";
import { DeepPartial } from "../../../../helpers";
/**
 * TxResponse defines a structure containing relevant tx data and metadata. The
 * tags are stringified and the log is JSON decoded.
 * @name TxResponse
 * @package cosmos.base.abci.v1beta1
 * @see proto type: cosmos.base.abci.v1beta1.TxResponse
 */
export interface TxResponse {
    /**
     * The block height
     */
    height: bigint;
    /**
     * The transaction hash.
     */
    txhash: string;
    /**
     * Namespace for the Code
     */
    codespace: string;
    /**
     * Response code.
     */
    code: number;
    /**
     * Result bytes, if any.
     */
    data: string;
    /**
     * The output of the application's logger (raw string). May be
     * non-deterministic.
     */
    rawLog: string;
    /**
     * The output of the application's logger (typed). May be non-deterministic.
     */
    logs: ABCIMessageLog[];
    /**
     * Additional information. May be non-deterministic.
     */
    info: string;
    /**
     * Amount of gas requested for transaction.
     */
    gasWanted: bigint;
    /**
     * Amount of gas consumed by transaction.
     */
    gasUsed: bigint;
    /**
     * The request transaction bytes.
     */
    tx?: Any;
    /**
     * Time of the previous block. For heights > 1, it's the weighted median of
     * the timestamps of the valid votes in the block.LastCommit. For height == 1,
     * it's genesis time.
     */
    timestamp: string;
    /**
     * Events defines all the events emitted by processing a transaction. Note,
     * these events include those emitted by processing all the messages and those
     * emitted from the ante. Whereas Logs contains the events, with
     * additional metadata, emitted only by processing the messages.
     */
    events: Event[];
}
/**
 * ABCIMessageLog defines a structure containing an indexed tx ABCI message log.
 * @name ABCIMessageLog
 * @package cosmos.base.abci.v1beta1
 * @see proto type: cosmos.base.abci.v1beta1.ABCIMessageLog
 */
export interface ABCIMessageLog {
    msgIndex: number;
    log: string;
    /**
     * Events contains a slice of Event objects that were emitted during some
     * execution.
     */
    events: StringEvent[];
}
/**
 * StringEvent defines en Event object wrapper where all the attributes
 * contain key/value pairs that are strings instead of raw bytes.
 * @name StringEvent
 * @package cosmos.base.abci.v1beta1
 * @see proto type: cosmos.base.abci.v1beta1.StringEvent
 */
export interface StringEvent {
    type: string;
    attributes: Attribute[];
}
/**
 * Attribute defines an attribute wrapper where the key and value are
 * strings instead of raw bytes.
 * @name Attribute
 * @package cosmos.base.abci.v1beta1
 * @see proto type: cosmos.base.abci.v1beta1.Attribute
 */
export interface Attribute {
    key: string;
    value: string;
}
/**
 * GasInfo defines tx execution gas context.
 * @name GasInfo
 * @package cosmos.base.abci.v1beta1
 * @see proto type: cosmos.base.abci.v1beta1.GasInfo
 */
export interface GasInfo {
    /**
     * GasWanted is the maximum units of work we allow this tx to perform.
     */
    gasWanted: bigint;
    /**
     * GasUsed is the amount of gas actually consumed.
     */
    gasUsed: bigint;
}
/**
 * Result is the union of ResponseFormat and ResponseCheckTx.
 * @name Result
 * @package cosmos.base.abci.v1beta1
 * @see proto type: cosmos.base.abci.v1beta1.Result
 */
export interface Result {
    /**
     * Data is any data returned from message or handler execution. It MUST be
     * length prefixed in order to separate data from multiple message executions.
     * Deprecated. This field is still populated, but prefer msg_response instead
     * because it also contains the Msg response typeURL.
     * @deprecated
     */
    data: Uint8Array;
    /**
     * Log contains the log information from message or handler execution.
     */
    log: string;
    /**
     * Events contains a slice of Event objects that were emitted during message
     * or handler execution.
     */
    events: Event[];
    /**
     * msg_responses contains the Msg handler responses type packed in Anys.
     */
    msgResponses: Any[];
}
/**
 * SimulationResponse defines the response generated when a transaction is
 * successfully simulated.
 * @name SimulationResponse
 * @package cosmos.base.abci.v1beta1
 * @see proto type: cosmos.base.abci.v1beta1.SimulationResponse
 */
export interface SimulationResponse {
    gasInfo: GasInfo;
    result?: Result;
}
/**
 * MsgData defines the data returned in a Result object during message
 * execution.
 * @name MsgData
 * @package cosmos.base.abci.v1beta1
 * @see proto type: cosmos.base.abci.v1beta1.MsgData
 * @deprecated
 */
export interface MsgData {
    msgType: string;
    data: Uint8Array;
}
/**
 * TxMsgData defines a list of MsgData. A transaction will have a MsgData object
 * for each message.
 * @name TxMsgData
 * @package cosmos.base.abci.v1beta1
 * @see proto type: cosmos.base.abci.v1beta1.TxMsgData
 */
export interface TxMsgData {
    /**
     * data field is deprecated and not populated.
     * @deprecated
     */
    data: MsgData[];
    /**
     * msg_responses contains the Msg handler responses packed into Anys.
     */
    msgResponses: Any[];
}
/**
 * SearchTxsResult defines a structure for querying txs pageable
 * @name SearchTxsResult
 * @package cosmos.base.abci.v1beta1
 * @see proto type: cosmos.base.abci.v1beta1.SearchTxsResult
 */
export interface SearchTxsResult {
    /**
     * Count of all txs
     */
    totalCount: bigint;
    /**
     * Count of txs in current page
     */
    count: bigint;
    /**
     * Index of current page, start from 1
     */
    pageNumber: bigint;
    /**
     * Count of total pages
     */
    pageTotal: bigint;
    /**
     * Max count txs per page
     */
    limit: bigint;
    /**
     * List of txs in current page
     */
    txs: TxResponse[];
}
/**
 * SearchBlocksResult defines a structure for querying blocks pageable
 * @name SearchBlocksResult
 * @package cosmos.base.abci.v1beta1
 * @see proto type: cosmos.base.abci.v1beta1.SearchBlocksResult
 */
export interface SearchBlocksResult {
    /**
     * Count of all blocks
     */
    totalCount: bigint;
    /**
     * Count of blocks in current page
     */
    count: bigint;
    /**
     * Index of current page, start from 1
     */
    pageNumber: bigint;
    /**
     * Count of total pages
     */
    pageTotal: bigint;
    /**
     * Max count blocks per page
     */
    limit: bigint;
    /**
     * List of blocks in current page
     */
    blocks: Block[];
}
/**
 * TxResponse defines a structure containing relevant tx data and metadata. The
 * tags are stringified and the log is JSON decoded.
 * @name TxResponse
 * @package cosmos.base.abci.v1beta1
 * @see proto type: cosmos.base.abci.v1beta1.TxResponse
 */
export declare const TxResponse: {
    typeUrl: string;
    aminoType: string;
    encode(message: TxResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): TxResponse;
    fromPartial(object: DeepPartial<TxResponse>): TxResponse;
};
/**
 * ABCIMessageLog defines a structure containing an indexed tx ABCI message log.
 * @name ABCIMessageLog
 * @package cosmos.base.abci.v1beta1
 * @see proto type: cosmos.base.abci.v1beta1.ABCIMessageLog
 */
export declare const ABCIMessageLog: {
    typeUrl: string;
    aminoType: string;
    encode(message: ABCIMessageLog, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ABCIMessageLog;
    fromPartial(object: DeepPartial<ABCIMessageLog>): ABCIMessageLog;
};
/**
 * StringEvent defines en Event object wrapper where all the attributes
 * contain key/value pairs that are strings instead of raw bytes.
 * @name StringEvent
 * @package cosmos.base.abci.v1beta1
 * @see proto type: cosmos.base.abci.v1beta1.StringEvent
 */
export declare const StringEvent: {
    typeUrl: string;
    aminoType: string;
    encode(message: StringEvent, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): StringEvent;
    fromPartial(object: DeepPartial<StringEvent>): StringEvent;
};
/**
 * Attribute defines an attribute wrapper where the key and value are
 * strings instead of raw bytes.
 * @name Attribute
 * @package cosmos.base.abci.v1beta1
 * @see proto type: cosmos.base.abci.v1beta1.Attribute
 */
export declare const Attribute: {
    typeUrl: string;
    aminoType: string;
    encode(message: Attribute, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Attribute;
    fromPartial(object: DeepPartial<Attribute>): Attribute;
};
/**
 * GasInfo defines tx execution gas context.
 * @name GasInfo
 * @package cosmos.base.abci.v1beta1
 * @see proto type: cosmos.base.abci.v1beta1.GasInfo
 */
export declare const GasInfo: {
    typeUrl: string;
    aminoType: string;
    encode(message: GasInfo, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): GasInfo;
    fromPartial(object: DeepPartial<GasInfo>): GasInfo;
};
/**
 * Result is the union of ResponseFormat and ResponseCheckTx.
 * @name Result
 * @package cosmos.base.abci.v1beta1
 * @see proto type: cosmos.base.abci.v1beta1.Result
 */
export declare const Result: {
    typeUrl: string;
    aminoType: string;
    encode(message: Result, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Result;
    fromPartial(object: DeepPartial<Result>): Result;
};
/**
 * SimulationResponse defines the response generated when a transaction is
 * successfully simulated.
 * @name SimulationResponse
 * @package cosmos.base.abci.v1beta1
 * @see proto type: cosmos.base.abci.v1beta1.SimulationResponse
 */
export declare const SimulationResponse: {
    typeUrl: string;
    aminoType: string;
    encode(message: SimulationResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): SimulationResponse;
    fromPartial(object: DeepPartial<SimulationResponse>): SimulationResponse;
};
/**
 * MsgData defines the data returned in a Result object during message
 * execution.
 * @name MsgData
 * @package cosmos.base.abci.v1beta1
 * @see proto type: cosmos.base.abci.v1beta1.MsgData
 * @deprecated
 */
export declare const MsgData: {
    typeUrl: string;
    aminoType: string;
    encode(message: MsgData, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): MsgData;
    fromPartial(object: DeepPartial<MsgData>): MsgData;
};
/**
 * TxMsgData defines a list of MsgData. A transaction will have a MsgData object
 * for each message.
 * @name TxMsgData
 * @package cosmos.base.abci.v1beta1
 * @see proto type: cosmos.base.abci.v1beta1.TxMsgData
 */
export declare const TxMsgData: {
    typeUrl: string;
    aminoType: string;
    encode(message: TxMsgData, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): TxMsgData;
    fromPartial(object: DeepPartial<TxMsgData>): TxMsgData;
};
/**
 * SearchTxsResult defines a structure for querying txs pageable
 * @name SearchTxsResult
 * @package cosmos.base.abci.v1beta1
 * @see proto type: cosmos.base.abci.v1beta1.SearchTxsResult
 */
export declare const SearchTxsResult: {
    typeUrl: string;
    aminoType: string;
    encode(message: SearchTxsResult, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): SearchTxsResult;
    fromPartial(object: DeepPartial<SearchTxsResult>): SearchTxsResult;
};
/**
 * SearchBlocksResult defines a structure for querying blocks pageable
 * @name SearchBlocksResult
 * @package cosmos.base.abci.v1beta1
 * @see proto type: cosmos.base.abci.v1beta1.SearchBlocksResult
 */
export declare const SearchBlocksResult: {
    typeUrl: string;
    aminoType: string;
    encode(message: SearchBlocksResult, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): SearchBlocksResult;
    fromPartial(object: DeepPartial<SearchBlocksResult>): SearchBlocksResult;
};
