import { BinaryReader, BinaryWriter } from "../../../binary";
import { DeepPartial } from "../../../helpers";
/**
 * PubKey is an ed25519 public key for handling Tendermint keys in SDK.
 * It's needed for Any serialization and SDK compatibility.
 * It must not be used in a non Tendermint key context because it doesn't implement
 * ADR-28. Nevertheless, you will like to use ed25519 in app user level
 * then you must create a new proto message and follow ADR-28 for Address construction.
 * @name PubKey
 * @package cosmos.crypto.ed25519
 * @see proto type: cosmos.crypto.ed25519.PubKey
 */
export interface PubKey {
    key: Uint8Array;
}
/**
 * PrivKey defines a ed25519 private key.
 * NOTE: ed25519 keys must not be used in SDK apps except in a tendermint validator context.
 * @name PrivKey
 * @package cosmos.crypto.ed25519
 * @see proto type: cosmos.crypto.ed25519.PrivKey
 */
export interface PrivKey {
    key: Uint8Array;
}
/**
 * PubKey is an ed25519 public key for handling Tendermint keys in SDK.
 * It's needed for Any serialization and SDK compatibility.
 * It must not be used in a non Tendermint key context because it doesn't implement
 * ADR-28. Nevertheless, you will like to use ed25519 in app user level
 * then you must create a new proto message and follow ADR-28 for Address construction.
 * @name PubKey
 * @package cosmos.crypto.ed25519
 * @see proto type: cosmos.crypto.ed25519.PubKey
 */
export declare const PubKey: {
    typeUrl: string;
    aminoType: string;
    encode(message: PubKey, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): PubKey;
    fromPartial(object: DeepPartial<PubKey>): PubKey;
};
/**
 * PrivKey defines a ed25519 private key.
 * NOTE: ed25519 keys must not be used in SDK apps except in a tendermint validator context.
 * @name PrivKey
 * @package cosmos.crypto.ed25519
 * @see proto type: cosmos.crypto.ed25519.PrivKey
 */
export declare const PrivKey: {
    typeUrl: string;
    aminoType: string;
    encode(message: PrivKey, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): PrivKey;
    fromPartial(object: DeepPartial<PrivKey>): PrivKey;
};
