import { Coin } from "../../base/v1beta1/coin";
import { Any } from "../../../google/protobuf/any";
import { Duration } from "../../../google/protobuf/duration";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { DeepPartial } from "../../../helpers";
/** VoteOption enumerates the valid vote options for a given governance proposal. */
export declare enum VoteOption {
    /** VOTE_OPTION_UNSPECIFIED - VOTE_OPTION_UNSPECIFIED defines a no-op vote option. */
    VOTE_OPTION_UNSPECIFIED = 0,
    /** VOTE_OPTION_YES - VOTE_OPTION_YES defines a yes vote option. */
    VOTE_OPTION_YES = 1,
    /** VOTE_OPTION_ABSTAIN - VOTE_OPTION_ABSTAIN defines an abstain vote option. */
    VOTE_OPTION_ABSTAIN = 2,
    /** VOTE_OPTION_NO - VOTE_OPTION_NO defines a no vote option. */
    VOTE_OPTION_NO = 3,
    /** VOTE_OPTION_NO_WITH_VETO - VOTE_OPTION_NO_WITH_VETO defines a no with veto vote option. */
    VOTE_OPTION_NO_WITH_VETO = 4,
    UNRECOGNIZED = -1
}
export declare function voteOptionFromJSON(object: any): VoteOption;
export declare function voteOptionToJSON(object: VoteOption): string;
/** ProposalStatus enumerates the valid statuses of a proposal. */
export declare enum ProposalStatus {
    /** PROPOSAL_STATUS_UNSPECIFIED - PROPOSAL_STATUS_UNSPECIFIED defines the default proposal status. */
    PROPOSAL_STATUS_UNSPECIFIED = 0,
    /**
     * PROPOSAL_STATUS_DEPOSIT_PERIOD - PROPOSAL_STATUS_DEPOSIT_PERIOD defines a proposal status during the deposit
     * period.
     */
    PROPOSAL_STATUS_DEPOSIT_PERIOD = 1,
    /**
     * PROPOSAL_STATUS_VOTING_PERIOD - PROPOSAL_STATUS_VOTING_PERIOD defines a proposal status during the voting
     * period.
     */
    PROPOSAL_STATUS_VOTING_PERIOD = 2,
    /**
     * PROPOSAL_STATUS_PASSED - PROPOSAL_STATUS_PASSED defines a proposal status of a proposal that has
     * passed.
     */
    PROPOSAL_STATUS_PASSED = 3,
    /**
     * PROPOSAL_STATUS_REJECTED - PROPOSAL_STATUS_REJECTED defines a proposal status of a proposal that has
     * been rejected.
     */
    PROPOSAL_STATUS_REJECTED = 4,
    /**
     * PROPOSAL_STATUS_FAILED - PROPOSAL_STATUS_FAILED defines a proposal status of a proposal that has
     * failed.
     */
    PROPOSAL_STATUS_FAILED = 5,
    UNRECOGNIZED = -1
}
export declare function proposalStatusFromJSON(object: any): ProposalStatus;
export declare function proposalStatusToJSON(object: ProposalStatus): string;
/**
 * WeightedVoteOption defines a unit of vote for vote split.
 * @name WeightedVoteOption
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.WeightedVoteOption
 */
export interface WeightedVoteOption {
    /**
     * option defines the valid vote options, it must not contain duplicate vote options.
     */
    option: VoteOption;
    /**
     * weight is the vote weight associated with the vote option.
     */
    weight: string;
}
/**
 * TextProposal defines a standard text proposal whose changes need to be
 * manually updated in case of approval.
 * @name TextProposal
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.TextProposal
 */
export interface TextProposal {
    /**
     * title of the proposal.
     */
    title: string;
    /**
     * description associated with the proposal.
     */
    description: string;
}
/**
 * Deposit defines an amount deposited by an account address to an active
 * proposal.
 * @name Deposit
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.Deposit
 */
export interface Deposit {
    /**
     * proposal_id defines the unique id of the proposal.
     */
    proposalId: bigint;
    /**
     * depositor defines the deposit addresses from the proposals.
     */
    depositor: string;
    /**
     * amount to be deposited by depositor.
     */
    amount: Coin[];
}
/**
 * Proposal defines the core field members of a governance proposal.
 * @name Proposal
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.Proposal
 */
export interface Proposal {
    /**
     * proposal_id defines the unique id of the proposal.
     */
    proposalId: bigint;
    /**
     * content is the proposal's content.
     */
    content?: Any;
    /**
     * status defines the proposal status.
     */
    status: ProposalStatus;
    /**
     * final_tally_result is the final tally result of the proposal. When
     * querying a proposal via gRPC, this field is not populated until the
     * proposal's voting period has ended.
     */
    finalTallyResult: TallyResult;
    /**
     * submit_time is the time of proposal submission.
     */
    submitTime: Date;
    /**
     * deposit_end_time is the end time for deposition.
     */
    depositEndTime: Date;
    /**
     * total_deposit is the total deposit on the proposal.
     */
    totalDeposit: Coin[];
    /**
     * voting_start_time is the starting time to vote on a proposal.
     */
    votingStartTime: Date;
    /**
     * voting_end_time is the end time of voting on a proposal.
     */
    votingEndTime: Date;
}
/**
 * TallyResult defines a standard tally for a governance proposal.
 * @name TallyResult
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.TallyResult
 */
export interface TallyResult {
    /**
     * yes is the number of yes votes on a proposal.
     */
    yes: string;
    /**
     * abstain is the number of abstain votes on a proposal.
     */
    abstain: string;
    /**
     * no is the number of no votes on a proposal.
     */
    no: string;
    /**
     * no_with_veto is the number of no with veto votes on a proposal.
     */
    noWithVeto: string;
}
/**
 * Vote defines a vote on a governance proposal.
 * A Vote consists of a proposal ID, the voter, and the vote option.
 * @name Vote
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.Vote
 */
export interface Vote {
    /**
     * proposal_id defines the unique id of the proposal.
     */
    proposalId: bigint;
    /**
     * voter is the voter address of the proposal.
     */
    voter: string;
    /**
     * Deprecated: Prefer to use `options` instead. This field is set in queries
     * if and only if `len(options) == 1` and that option has weight 1. In all
     * other cases, this field will default to VOTE_OPTION_UNSPECIFIED.
     * @deprecated
     */
    option: VoteOption;
    /**
     * options is the weighted vote options.
     */
    options: WeightedVoteOption[];
}
/**
 * DepositParams defines the params for deposits on governance proposals.
 * @name DepositParams
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.DepositParams
 */
export interface DepositParams {
    /**
     * Minimum deposit for a proposal to enter voting period.
     */
    minDeposit: Coin[];
    /**
     * Maximum period for Atom holders to deposit on a proposal. Initial value: 2
     * months.
     */
    maxDepositPeriod: Duration;
}
/**
 * VotingParams defines the params for voting on governance proposals.
 * @name VotingParams
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.VotingParams
 */
export interface VotingParams {
    /**
     * Duration of the voting period.
     */
    votingPeriod: Duration;
}
/**
 * TallyParams defines the params for tallying votes on governance proposals.
 * @name TallyParams
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.TallyParams
 */
export interface TallyParams {
    /**
     * Minimum percentage of total stake needed to vote for a result to be
     * considered valid.
     */
    quorum: Uint8Array;
    /**
     * Minimum proportion of Yes votes for proposal to pass. Default value: 0.5.
     */
    threshold: Uint8Array;
    /**
     * Minimum value of Veto votes to Total votes ratio for proposal to be
     * vetoed. Default value: 1/3.
     */
    vetoThreshold: Uint8Array;
}
/**
 * WeightedVoteOption defines a unit of vote for vote split.
 * @name WeightedVoteOption
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.WeightedVoteOption
 */
export declare const WeightedVoteOption: {
    typeUrl: string;
    aminoType: string;
    encode(message: WeightedVoteOption, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): WeightedVoteOption;
    fromPartial(object: DeepPartial<WeightedVoteOption>): WeightedVoteOption;
};
/**
 * TextProposal defines a standard text proposal whose changes need to be
 * manually updated in case of approval.
 * @name TextProposal
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.TextProposal
 */
export declare const TextProposal: {
    typeUrl: string;
    aminoType: string;
    encode(message: TextProposal, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): TextProposal;
    fromPartial(object: DeepPartial<TextProposal>): TextProposal;
};
/**
 * Deposit defines an amount deposited by an account address to an active
 * proposal.
 * @name Deposit
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.Deposit
 */
export declare const Deposit: {
    typeUrl: string;
    aminoType: string;
    encode(message: Deposit, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Deposit;
    fromPartial(object: DeepPartial<Deposit>): Deposit;
};
/**
 * Proposal defines the core field members of a governance proposal.
 * @name Proposal
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.Proposal
 */
export declare const Proposal: {
    typeUrl: string;
    aminoType: string;
    encode(message: Proposal, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Proposal;
    fromPartial(object: DeepPartial<Proposal>): Proposal;
};
/**
 * TallyResult defines a standard tally for a governance proposal.
 * @name TallyResult
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.TallyResult
 */
export declare const TallyResult: {
    typeUrl: string;
    aminoType: string;
    encode(message: TallyResult, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): TallyResult;
    fromPartial(object: DeepPartial<TallyResult>): TallyResult;
};
/**
 * Vote defines a vote on a governance proposal.
 * A Vote consists of a proposal ID, the voter, and the vote option.
 * @name Vote
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.Vote
 */
export declare const Vote: {
    typeUrl: string;
    aminoType: string;
    encode(message: Vote, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Vote;
    fromPartial(object: DeepPartial<Vote>): Vote;
};
/**
 * DepositParams defines the params for deposits on governance proposals.
 * @name DepositParams
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.DepositParams
 */
export declare const DepositParams: {
    typeUrl: string;
    aminoType: string;
    encode(message: DepositParams, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): DepositParams;
    fromPartial(object: DeepPartial<DepositParams>): DepositParams;
};
/**
 * VotingParams defines the params for voting on governance proposals.
 * @name VotingParams
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.VotingParams
 */
export declare const VotingParams: {
    typeUrl: string;
    aminoType: string;
    encode(message: VotingParams, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): VotingParams;
    fromPartial(object: DeepPartial<VotingParams>): VotingParams;
};
/**
 * TallyParams defines the params for tallying votes on governance proposals.
 * @name TallyParams
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.TallyParams
 */
export declare const TallyParams: {
    typeUrl: string;
    aminoType: string;
    encode(message: TallyParams, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): TallyParams;
    fromPartial(object: DeepPartial<TallyParams>): TallyParams;
};
