import { ProposalStatus, Proposal, Vote, VotingParams, DepositParams, TallyParams, Deposit, TallyResult } from "./gov";
import { PageRequest, PageResponse } from "../../base/query/v1beta1/pagination";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { DeepPartial } from "../../../helpers";
/**
 * QueryProposalRequest is the request type for the Query/Proposal RPC method.
 * @name QueryProposalRequest
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryProposalRequest
 */
export interface QueryProposalRequest {
    /**
     * proposal_id defines the unique id of the proposal.
     */
    proposalId: bigint;
}
/**
 * QueryProposalResponse is the response type for the Query/Proposal RPC method.
 * @name QueryProposalResponse
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryProposalResponse
 */
export interface QueryProposalResponse {
    proposal: Proposal;
}
/**
 * QueryProposalsRequest is the request type for the Query/Proposals RPC method.
 * @name QueryProposalsRequest
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryProposalsRequest
 */
export interface QueryProposalsRequest {
    /**
     * proposal_status defines the status of the proposals.
     */
    proposalStatus: ProposalStatus;
    /**
     * voter defines the voter address for the proposals.
     */
    voter: string;
    /**
     * depositor defines the deposit addresses from the proposals.
     */
    depositor: string;
    /**
     * pagination defines an optional pagination for the request.
     */
    pagination?: PageRequest;
}
/**
 * QueryProposalsResponse is the response type for the Query/Proposals RPC
 * method.
 * @name QueryProposalsResponse
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryProposalsResponse
 */
export interface QueryProposalsResponse {
    /**
     * proposals defines all the requested governance proposals.
     */
    proposals: Proposal[];
    /**
     * pagination defines the pagination in the response.
     */
    pagination?: PageResponse;
}
/**
 * QueryVoteRequest is the request type for the Query/Vote RPC method.
 * @name QueryVoteRequest
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryVoteRequest
 */
export interface QueryVoteRequest {
    /**
     * proposal_id defines the unique id of the proposal.
     */
    proposalId: bigint;
    /**
     * voter defines the voter address for the proposals.
     */
    voter: string;
}
/**
 * QueryVoteResponse is the response type for the Query/Vote RPC method.
 * @name QueryVoteResponse
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryVoteResponse
 */
export interface QueryVoteResponse {
    /**
     * vote defines the queried vote.
     */
    vote: Vote;
}
/**
 * QueryVotesRequest is the request type for the Query/Votes RPC method.
 * @name QueryVotesRequest
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryVotesRequest
 */
export interface QueryVotesRequest {
    /**
     * proposal_id defines the unique id of the proposal.
     */
    proposalId: bigint;
    /**
     * pagination defines an optional pagination for the request.
     */
    pagination?: PageRequest;
}
/**
 * QueryVotesResponse is the response type for the Query/Votes RPC method.
 * @name QueryVotesResponse
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryVotesResponse
 */
export interface QueryVotesResponse {
    /**
     * votes defines the queried votes.
     */
    votes: Vote[];
    /**
     * pagination defines the pagination in the response.
     */
    pagination?: PageResponse;
}
/**
 * QueryParamsRequest is the request type for the Query/Params RPC method.
 * @name QueryParamsRequest
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryParamsRequest
 */
export interface QueryParamsRequest {
    /**
     * params_type defines which parameters to query for, can be one of "voting",
     * "tallying" or "deposit".
     */
    paramsType: string;
}
/**
 * QueryParamsResponse is the response type for the Query/Params RPC method.
 * @name QueryParamsResponse
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryParamsResponse
 */
export interface QueryParamsResponse {
    /**
     * voting_params defines the parameters related to voting.
     */
    votingParams: VotingParams;
    /**
     * deposit_params defines the parameters related to deposit.
     */
    depositParams: DepositParams;
    /**
     * tally_params defines the parameters related to tally.
     */
    tallyParams: TallyParams;
}
/**
 * QueryDepositRequest is the request type for the Query/Deposit RPC method.
 * @name QueryDepositRequest
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryDepositRequest
 */
export interface QueryDepositRequest {
    /**
     * proposal_id defines the unique id of the proposal.
     */
    proposalId: bigint;
    /**
     * depositor defines the deposit addresses from the proposals.
     */
    depositor: string;
}
/**
 * QueryDepositResponse is the response type for the Query/Deposit RPC method.
 * @name QueryDepositResponse
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryDepositResponse
 */
export interface QueryDepositResponse {
    /**
     * deposit defines the requested deposit.
     */
    deposit: Deposit;
}
/**
 * QueryDepositsRequest is the request type for the Query/Deposits RPC method.
 * @name QueryDepositsRequest
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryDepositsRequest
 */
export interface QueryDepositsRequest {
    /**
     * proposal_id defines the unique id of the proposal.
     */
    proposalId: bigint;
    /**
     * pagination defines an optional pagination for the request.
     */
    pagination?: PageRequest;
}
/**
 * QueryDepositsResponse is the response type for the Query/Deposits RPC method.
 * @name QueryDepositsResponse
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryDepositsResponse
 */
export interface QueryDepositsResponse {
    /**
     * deposits defines the requested deposits.
     */
    deposits: Deposit[];
    /**
     * pagination defines the pagination in the response.
     */
    pagination?: PageResponse;
}
/**
 * QueryTallyResultRequest is the request type for the Query/Tally RPC method.
 * @name QueryTallyResultRequest
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryTallyResultRequest
 */
export interface QueryTallyResultRequest {
    /**
     * proposal_id defines the unique id of the proposal.
     */
    proposalId: bigint;
}
/**
 * QueryTallyResultResponse is the response type for the Query/Tally RPC method.
 * @name QueryTallyResultResponse
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryTallyResultResponse
 */
export interface QueryTallyResultResponse {
    /**
     * tally defines the requested tally.
     */
    tally: TallyResult;
}
/**
 * QueryProposalRequest is the request type for the Query/Proposal RPC method.
 * @name QueryProposalRequest
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryProposalRequest
 */
export declare const QueryProposalRequest: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryProposalRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryProposalRequest;
    fromPartial(object: DeepPartial<QueryProposalRequest>): QueryProposalRequest;
};
/**
 * QueryProposalResponse is the response type for the Query/Proposal RPC method.
 * @name QueryProposalResponse
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryProposalResponse
 */
export declare const QueryProposalResponse: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryProposalResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryProposalResponse;
    fromPartial(object: DeepPartial<QueryProposalResponse>): QueryProposalResponse;
};
/**
 * QueryProposalsRequest is the request type for the Query/Proposals RPC method.
 * @name QueryProposalsRequest
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryProposalsRequest
 */
export declare const QueryProposalsRequest: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryProposalsRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryProposalsRequest;
    fromPartial(object: DeepPartial<QueryProposalsRequest>): QueryProposalsRequest;
};
/**
 * QueryProposalsResponse is the response type for the Query/Proposals RPC
 * method.
 * @name QueryProposalsResponse
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryProposalsResponse
 */
export declare const QueryProposalsResponse: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryProposalsResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryProposalsResponse;
    fromPartial(object: DeepPartial<QueryProposalsResponse>): QueryProposalsResponse;
};
/**
 * QueryVoteRequest is the request type for the Query/Vote RPC method.
 * @name QueryVoteRequest
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryVoteRequest
 */
export declare const QueryVoteRequest: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryVoteRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryVoteRequest;
    fromPartial(object: DeepPartial<QueryVoteRequest>): QueryVoteRequest;
};
/**
 * QueryVoteResponse is the response type for the Query/Vote RPC method.
 * @name QueryVoteResponse
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryVoteResponse
 */
export declare const QueryVoteResponse: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryVoteResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryVoteResponse;
    fromPartial(object: DeepPartial<QueryVoteResponse>): QueryVoteResponse;
};
/**
 * QueryVotesRequest is the request type for the Query/Votes RPC method.
 * @name QueryVotesRequest
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryVotesRequest
 */
export declare const QueryVotesRequest: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryVotesRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryVotesRequest;
    fromPartial(object: DeepPartial<QueryVotesRequest>): QueryVotesRequest;
};
/**
 * QueryVotesResponse is the response type for the Query/Votes RPC method.
 * @name QueryVotesResponse
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryVotesResponse
 */
export declare const QueryVotesResponse: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryVotesResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryVotesResponse;
    fromPartial(object: DeepPartial<QueryVotesResponse>): QueryVotesResponse;
};
/**
 * QueryParamsRequest is the request type for the Query/Params RPC method.
 * @name QueryParamsRequest
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryParamsRequest
 */
export declare const QueryParamsRequest: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryParamsRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryParamsRequest;
    fromPartial(object: DeepPartial<QueryParamsRequest>): QueryParamsRequest;
};
/**
 * QueryParamsResponse is the response type for the Query/Params RPC method.
 * @name QueryParamsResponse
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryParamsResponse
 */
export declare const QueryParamsResponse: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryParamsResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryParamsResponse;
    fromPartial(object: DeepPartial<QueryParamsResponse>): QueryParamsResponse;
};
/**
 * QueryDepositRequest is the request type for the Query/Deposit RPC method.
 * @name QueryDepositRequest
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryDepositRequest
 */
export declare const QueryDepositRequest: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryDepositRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryDepositRequest;
    fromPartial(object: DeepPartial<QueryDepositRequest>): QueryDepositRequest;
};
/**
 * QueryDepositResponse is the response type for the Query/Deposit RPC method.
 * @name QueryDepositResponse
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryDepositResponse
 */
export declare const QueryDepositResponse: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryDepositResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryDepositResponse;
    fromPartial(object: DeepPartial<QueryDepositResponse>): QueryDepositResponse;
};
/**
 * QueryDepositsRequest is the request type for the Query/Deposits RPC method.
 * @name QueryDepositsRequest
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryDepositsRequest
 */
export declare const QueryDepositsRequest: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryDepositsRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryDepositsRequest;
    fromPartial(object: DeepPartial<QueryDepositsRequest>): QueryDepositsRequest;
};
/**
 * QueryDepositsResponse is the response type for the Query/Deposits RPC method.
 * @name QueryDepositsResponse
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryDepositsResponse
 */
export declare const QueryDepositsResponse: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryDepositsResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryDepositsResponse;
    fromPartial(object: DeepPartial<QueryDepositsResponse>): QueryDepositsResponse;
};
/**
 * QueryTallyResultRequest is the request type for the Query/Tally RPC method.
 * @name QueryTallyResultRequest
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryTallyResultRequest
 */
export declare const QueryTallyResultRequest: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryTallyResultRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryTallyResultRequest;
    fromPartial(object: DeepPartial<QueryTallyResultRequest>): QueryTallyResultRequest;
};
/**
 * QueryTallyResultResponse is the response type for the Query/Tally RPC method.
 * @name QueryTallyResultResponse
 * @package cosmos.gov.v1beta1
 * @see proto type: cosmos.gov.v1beta1.QueryTallyResultResponse
 */
export declare const QueryTallyResultResponse: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryTallyResultResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryTallyResultResponse;
    fromPartial(object: DeepPartial<QueryTallyResultResponse>): QueryTallyResultResponse;
};
