import { PageRequest, PageResponse } from "../../base/query/v1beta1/pagination";
import { Validator, DelegationResponse, UnbondingDelegation, RedelegationResponse, HistoricalInfo, Pool, Params } from "./staking";
import { BinaryReader, BinaryWriter } from "../../../binary";
import { DeepPartial } from "../../../helpers";
/**
 * QueryValidatorsRequest is request type for Query/Validators RPC method.
 * @name QueryValidatorsRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryValidatorsRequest
 */
export interface QueryValidatorsRequest {
    /**
     * status enables to query for validators matching a given status.
     */
    status: string;
    /**
     * pagination defines an optional pagination for the request.
     */
    pagination?: PageRequest;
}
/**
 * QueryValidatorsResponse is response type for the Query/Validators RPC method
 * @name QueryValidatorsResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryValidatorsResponse
 */
export interface QueryValidatorsResponse {
    /**
     * validators contains all the queried validators.
     */
    validators: Validator[];
    /**
     * pagination defines the pagination in the response.
     */
    pagination?: PageResponse;
}
/**
 * QueryValidatorRequest is response type for the Query/Validator RPC method
 * @name QueryValidatorRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryValidatorRequest
 */
export interface QueryValidatorRequest {
    /**
     * validator_addr defines the validator address to query for.
     */
    validatorAddr: string;
}
/**
 * QueryValidatorResponse is response type for the Query/Validator RPC method
 * @name QueryValidatorResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryValidatorResponse
 */
export interface QueryValidatorResponse {
    /**
     * validator defines the validator info.
     */
    validator: Validator;
}
/**
 * QueryValidatorDelegationsRequest is request type for the
 * Query/ValidatorDelegations RPC method
 * @name QueryValidatorDelegationsRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryValidatorDelegationsRequest
 */
export interface QueryValidatorDelegationsRequest {
    /**
     * validator_addr defines the validator address to query for.
     */
    validatorAddr: string;
    /**
     * pagination defines an optional pagination for the request.
     */
    pagination?: PageRequest;
}
/**
 * QueryValidatorDelegationsResponse is response type for the
 * Query/ValidatorDelegations RPC method
 * @name QueryValidatorDelegationsResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryValidatorDelegationsResponse
 */
export interface QueryValidatorDelegationsResponse {
    delegationResponses: DelegationResponse[];
    /**
     * pagination defines the pagination in the response.
     */
    pagination?: PageResponse;
}
/**
 * QueryValidatorUnbondingDelegationsRequest is required type for the
 * Query/ValidatorUnbondingDelegations RPC method
 * @name QueryValidatorUnbondingDelegationsRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsRequest
 */
export interface QueryValidatorUnbondingDelegationsRequest {
    /**
     * validator_addr defines the validator address to query for.
     */
    validatorAddr: string;
    /**
     * pagination defines an optional pagination for the request.
     */
    pagination?: PageRequest;
}
/**
 * QueryValidatorUnbondingDelegationsResponse is response type for the
 * Query/ValidatorUnbondingDelegations RPC method.
 * @name QueryValidatorUnbondingDelegationsResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsResponse
 */
export interface QueryValidatorUnbondingDelegationsResponse {
    unbondingResponses: UnbondingDelegation[];
    /**
     * pagination defines the pagination in the response.
     */
    pagination?: PageResponse;
}
/**
 * QueryDelegationRequest is request type for the Query/Delegation RPC method.
 * @name QueryDelegationRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryDelegationRequest
 */
export interface QueryDelegationRequest {
    /**
     * delegator_addr defines the delegator address to query for.
     */
    delegatorAddr: string;
    /**
     * validator_addr defines the validator address to query for.
     */
    validatorAddr: string;
}
/**
 * QueryDelegationResponse is response type for the Query/Delegation RPC method.
 * @name QueryDelegationResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryDelegationResponse
 */
export interface QueryDelegationResponse {
    /**
     * delegation_responses defines the delegation info of a delegation.
     */
    delegationResponse?: DelegationResponse;
}
/**
 * QueryUnbondingDelegationRequest is request type for the
 * Query/UnbondingDelegation RPC method.
 * @name QueryUnbondingDelegationRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryUnbondingDelegationRequest
 */
export interface QueryUnbondingDelegationRequest {
    /**
     * delegator_addr defines the delegator address to query for.
     */
    delegatorAddr: string;
    /**
     * validator_addr defines the validator address to query for.
     */
    validatorAddr: string;
}
/**
 * QueryDelegationResponse is response type for the Query/UnbondingDelegation
 * RPC method.
 * @name QueryUnbondingDelegationResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryUnbondingDelegationResponse
 */
export interface QueryUnbondingDelegationResponse {
    /**
     * unbond defines the unbonding information of a delegation.
     */
    unbond: UnbondingDelegation;
}
/**
 * QueryDelegatorDelegationsRequest is request type for the
 * Query/DelegatorDelegations RPC method.
 * @name QueryDelegatorDelegationsRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryDelegatorDelegationsRequest
 */
export interface QueryDelegatorDelegationsRequest {
    /**
     * delegator_addr defines the delegator address to query for.
     */
    delegatorAddr: string;
    /**
     * pagination defines an optional pagination for the request.
     */
    pagination?: PageRequest;
}
/**
 * QueryDelegatorDelegationsResponse is response type for the
 * Query/DelegatorDelegations RPC method.
 * @name QueryDelegatorDelegationsResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryDelegatorDelegationsResponse
 */
export interface QueryDelegatorDelegationsResponse {
    /**
     * delegation_responses defines all the delegations' info of a delegator.
     */
    delegationResponses: DelegationResponse[];
    /**
     * pagination defines the pagination in the response.
     */
    pagination?: PageResponse;
}
/**
 * QueryDelegatorUnbondingDelegationsRequest is request type for the
 * Query/DelegatorUnbondingDelegations RPC method.
 * @name QueryDelegatorUnbondingDelegationsRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsRequest
 */
export interface QueryDelegatorUnbondingDelegationsRequest {
    /**
     * delegator_addr defines the delegator address to query for.
     */
    delegatorAddr: string;
    /**
     * pagination defines an optional pagination for the request.
     */
    pagination?: PageRequest;
}
/**
 * QueryUnbondingDelegatorDelegationsResponse is response type for the
 * Query/UnbondingDelegatorDelegations RPC method.
 * @name QueryDelegatorUnbondingDelegationsResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsResponse
 */
export interface QueryDelegatorUnbondingDelegationsResponse {
    unbondingResponses: UnbondingDelegation[];
    /**
     * pagination defines the pagination in the response.
     */
    pagination?: PageResponse;
}
/**
 * QueryRedelegationsRequest is request type for the Query/Redelegations RPC
 * method.
 * @name QueryRedelegationsRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryRedelegationsRequest
 */
export interface QueryRedelegationsRequest {
    /**
     * delegator_addr defines the delegator address to query for.
     */
    delegatorAddr: string;
    /**
     * src_validator_addr defines the validator address to redelegate from.
     */
    srcValidatorAddr: string;
    /**
     * dst_validator_addr defines the validator address to redelegate to.
     */
    dstValidatorAddr: string;
    /**
     * pagination defines an optional pagination for the request.
     */
    pagination?: PageRequest;
}
/**
 * QueryRedelegationsResponse is response type for the Query/Redelegations RPC
 * method.
 * @name QueryRedelegationsResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryRedelegationsResponse
 */
export interface QueryRedelegationsResponse {
    redelegationResponses: RedelegationResponse[];
    /**
     * pagination defines the pagination in the response.
     */
    pagination?: PageResponse;
}
/**
 * QueryDelegatorValidatorsRequest is request type for the
 * Query/DelegatorValidators RPC method.
 * @name QueryDelegatorValidatorsRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryDelegatorValidatorsRequest
 */
export interface QueryDelegatorValidatorsRequest {
    /**
     * delegator_addr defines the delegator address to query for.
     */
    delegatorAddr: string;
    /**
     * pagination defines an optional pagination for the request.
     */
    pagination?: PageRequest;
}
/**
 * QueryDelegatorValidatorsResponse is response type for the
 * Query/DelegatorValidators RPC method.
 * @name QueryDelegatorValidatorsResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryDelegatorValidatorsResponse
 */
export interface QueryDelegatorValidatorsResponse {
    /**
     * validators defines the validators' info of a delegator.
     */
    validators: Validator[];
    /**
     * pagination defines the pagination in the response.
     */
    pagination?: PageResponse;
}
/**
 * QueryDelegatorValidatorRequest is request type for the
 * Query/DelegatorValidator RPC method.
 * @name QueryDelegatorValidatorRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryDelegatorValidatorRequest
 */
export interface QueryDelegatorValidatorRequest {
    /**
     * delegator_addr defines the delegator address to query for.
     */
    delegatorAddr: string;
    /**
     * validator_addr defines the validator address to query for.
     */
    validatorAddr: string;
}
/**
 * QueryDelegatorValidatorResponse response type for the
 * Query/DelegatorValidator RPC method.
 * @name QueryDelegatorValidatorResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryDelegatorValidatorResponse
 */
export interface QueryDelegatorValidatorResponse {
    /**
     * validator defines the validator info.
     */
    validator: Validator;
}
/**
 * QueryHistoricalInfoRequest is request type for the Query/HistoricalInfo RPC
 * method.
 * @name QueryHistoricalInfoRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryHistoricalInfoRequest
 */
export interface QueryHistoricalInfoRequest {
    /**
     * height defines at which height to query the historical info.
     */
    height: bigint;
}
/**
 * QueryHistoricalInfoResponse is response type for the Query/HistoricalInfo RPC
 * method.
 * @name QueryHistoricalInfoResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryHistoricalInfoResponse
 */
export interface QueryHistoricalInfoResponse {
    /**
     * hist defines the historical info at the given height.
     */
    hist?: HistoricalInfo;
}
/**
 * QueryPoolRequest is request type for the Query/Pool RPC method.
 * @name QueryPoolRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryPoolRequest
 */
export interface QueryPoolRequest {
}
/**
 * QueryPoolResponse is response type for the Query/Pool RPC method.
 * @name QueryPoolResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryPoolResponse
 */
export interface QueryPoolResponse {
    /**
     * pool defines the pool info.
     */
    pool: Pool;
}
/**
 * QueryParamsRequest is request type for the Query/Params RPC method.
 * @name QueryParamsRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryParamsRequest
 */
export interface QueryParamsRequest {
}
/**
 * QueryParamsResponse is response type for the Query/Params RPC method.
 * @name QueryParamsResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryParamsResponse
 */
export interface QueryParamsResponse {
    /**
     * params holds all the parameters of this module.
     */
    params: Params;
}
/**
 * QueryValidatorsRequest is request type for Query/Validators RPC method.
 * @name QueryValidatorsRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryValidatorsRequest
 */
export declare const QueryValidatorsRequest: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryValidatorsRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryValidatorsRequest;
    fromPartial(object: DeepPartial<QueryValidatorsRequest>): QueryValidatorsRequest;
};
/**
 * QueryValidatorsResponse is response type for the Query/Validators RPC method
 * @name QueryValidatorsResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryValidatorsResponse
 */
export declare const QueryValidatorsResponse: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryValidatorsResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryValidatorsResponse;
    fromPartial(object: DeepPartial<QueryValidatorsResponse>): QueryValidatorsResponse;
};
/**
 * QueryValidatorRequest is response type for the Query/Validator RPC method
 * @name QueryValidatorRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryValidatorRequest
 */
export declare const QueryValidatorRequest: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryValidatorRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryValidatorRequest;
    fromPartial(object: DeepPartial<QueryValidatorRequest>): QueryValidatorRequest;
};
/**
 * QueryValidatorResponse is response type for the Query/Validator RPC method
 * @name QueryValidatorResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryValidatorResponse
 */
export declare const QueryValidatorResponse: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryValidatorResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryValidatorResponse;
    fromPartial(object: DeepPartial<QueryValidatorResponse>): QueryValidatorResponse;
};
/**
 * QueryValidatorDelegationsRequest is request type for the
 * Query/ValidatorDelegations RPC method
 * @name QueryValidatorDelegationsRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryValidatorDelegationsRequest
 */
export declare const QueryValidatorDelegationsRequest: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryValidatorDelegationsRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryValidatorDelegationsRequest;
    fromPartial(object: DeepPartial<QueryValidatorDelegationsRequest>): QueryValidatorDelegationsRequest;
};
/**
 * QueryValidatorDelegationsResponse is response type for the
 * Query/ValidatorDelegations RPC method
 * @name QueryValidatorDelegationsResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryValidatorDelegationsResponse
 */
export declare const QueryValidatorDelegationsResponse: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryValidatorDelegationsResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryValidatorDelegationsResponse;
    fromPartial(object: DeepPartial<QueryValidatorDelegationsResponse>): QueryValidatorDelegationsResponse;
};
/**
 * QueryValidatorUnbondingDelegationsRequest is required type for the
 * Query/ValidatorUnbondingDelegations RPC method
 * @name QueryValidatorUnbondingDelegationsRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsRequest
 */
export declare const QueryValidatorUnbondingDelegationsRequest: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryValidatorUnbondingDelegationsRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryValidatorUnbondingDelegationsRequest;
    fromPartial(object: DeepPartial<QueryValidatorUnbondingDelegationsRequest>): QueryValidatorUnbondingDelegationsRequest;
};
/**
 * QueryValidatorUnbondingDelegationsResponse is response type for the
 * Query/ValidatorUnbondingDelegations RPC method.
 * @name QueryValidatorUnbondingDelegationsResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsResponse
 */
export declare const QueryValidatorUnbondingDelegationsResponse: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryValidatorUnbondingDelegationsResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryValidatorUnbondingDelegationsResponse;
    fromPartial(object: DeepPartial<QueryValidatorUnbondingDelegationsResponse>): QueryValidatorUnbondingDelegationsResponse;
};
/**
 * QueryDelegationRequest is request type for the Query/Delegation RPC method.
 * @name QueryDelegationRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryDelegationRequest
 */
export declare const QueryDelegationRequest: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryDelegationRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryDelegationRequest;
    fromPartial(object: DeepPartial<QueryDelegationRequest>): QueryDelegationRequest;
};
/**
 * QueryDelegationResponse is response type for the Query/Delegation RPC method.
 * @name QueryDelegationResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryDelegationResponse
 */
export declare const QueryDelegationResponse: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryDelegationResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryDelegationResponse;
    fromPartial(object: DeepPartial<QueryDelegationResponse>): QueryDelegationResponse;
};
/**
 * QueryUnbondingDelegationRequest is request type for the
 * Query/UnbondingDelegation RPC method.
 * @name QueryUnbondingDelegationRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryUnbondingDelegationRequest
 */
export declare const QueryUnbondingDelegationRequest: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryUnbondingDelegationRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryUnbondingDelegationRequest;
    fromPartial(object: DeepPartial<QueryUnbondingDelegationRequest>): QueryUnbondingDelegationRequest;
};
/**
 * QueryDelegationResponse is response type for the Query/UnbondingDelegation
 * RPC method.
 * @name QueryUnbondingDelegationResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryUnbondingDelegationResponse
 */
export declare const QueryUnbondingDelegationResponse: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryUnbondingDelegationResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryUnbondingDelegationResponse;
    fromPartial(object: DeepPartial<QueryUnbondingDelegationResponse>): QueryUnbondingDelegationResponse;
};
/**
 * QueryDelegatorDelegationsRequest is request type for the
 * Query/DelegatorDelegations RPC method.
 * @name QueryDelegatorDelegationsRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryDelegatorDelegationsRequest
 */
export declare const QueryDelegatorDelegationsRequest: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryDelegatorDelegationsRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryDelegatorDelegationsRequest;
    fromPartial(object: DeepPartial<QueryDelegatorDelegationsRequest>): QueryDelegatorDelegationsRequest;
};
/**
 * QueryDelegatorDelegationsResponse is response type for the
 * Query/DelegatorDelegations RPC method.
 * @name QueryDelegatorDelegationsResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryDelegatorDelegationsResponse
 */
export declare const QueryDelegatorDelegationsResponse: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryDelegatorDelegationsResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryDelegatorDelegationsResponse;
    fromPartial(object: DeepPartial<QueryDelegatorDelegationsResponse>): QueryDelegatorDelegationsResponse;
};
/**
 * QueryDelegatorUnbondingDelegationsRequest is request type for the
 * Query/DelegatorUnbondingDelegations RPC method.
 * @name QueryDelegatorUnbondingDelegationsRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsRequest
 */
export declare const QueryDelegatorUnbondingDelegationsRequest: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryDelegatorUnbondingDelegationsRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryDelegatorUnbondingDelegationsRequest;
    fromPartial(object: DeepPartial<QueryDelegatorUnbondingDelegationsRequest>): QueryDelegatorUnbondingDelegationsRequest;
};
/**
 * QueryUnbondingDelegatorDelegationsResponse is response type for the
 * Query/UnbondingDelegatorDelegations RPC method.
 * @name QueryDelegatorUnbondingDelegationsResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsResponse
 */
export declare const QueryDelegatorUnbondingDelegationsResponse: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryDelegatorUnbondingDelegationsResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryDelegatorUnbondingDelegationsResponse;
    fromPartial(object: DeepPartial<QueryDelegatorUnbondingDelegationsResponse>): QueryDelegatorUnbondingDelegationsResponse;
};
/**
 * QueryRedelegationsRequest is request type for the Query/Redelegations RPC
 * method.
 * @name QueryRedelegationsRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryRedelegationsRequest
 */
export declare const QueryRedelegationsRequest: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryRedelegationsRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryRedelegationsRequest;
    fromPartial(object: DeepPartial<QueryRedelegationsRequest>): QueryRedelegationsRequest;
};
/**
 * QueryRedelegationsResponse is response type for the Query/Redelegations RPC
 * method.
 * @name QueryRedelegationsResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryRedelegationsResponse
 */
export declare const QueryRedelegationsResponse: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryRedelegationsResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryRedelegationsResponse;
    fromPartial(object: DeepPartial<QueryRedelegationsResponse>): QueryRedelegationsResponse;
};
/**
 * QueryDelegatorValidatorsRequest is request type for the
 * Query/DelegatorValidators RPC method.
 * @name QueryDelegatorValidatorsRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryDelegatorValidatorsRequest
 */
export declare const QueryDelegatorValidatorsRequest: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryDelegatorValidatorsRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryDelegatorValidatorsRequest;
    fromPartial(object: DeepPartial<QueryDelegatorValidatorsRequest>): QueryDelegatorValidatorsRequest;
};
/**
 * QueryDelegatorValidatorsResponse is response type for the
 * Query/DelegatorValidators RPC method.
 * @name QueryDelegatorValidatorsResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryDelegatorValidatorsResponse
 */
export declare const QueryDelegatorValidatorsResponse: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryDelegatorValidatorsResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryDelegatorValidatorsResponse;
    fromPartial(object: DeepPartial<QueryDelegatorValidatorsResponse>): QueryDelegatorValidatorsResponse;
};
/**
 * QueryDelegatorValidatorRequest is request type for the
 * Query/DelegatorValidator RPC method.
 * @name QueryDelegatorValidatorRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryDelegatorValidatorRequest
 */
export declare const QueryDelegatorValidatorRequest: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryDelegatorValidatorRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryDelegatorValidatorRequest;
    fromPartial(object: DeepPartial<QueryDelegatorValidatorRequest>): QueryDelegatorValidatorRequest;
};
/**
 * QueryDelegatorValidatorResponse response type for the
 * Query/DelegatorValidator RPC method.
 * @name QueryDelegatorValidatorResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryDelegatorValidatorResponse
 */
export declare const QueryDelegatorValidatorResponse: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryDelegatorValidatorResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryDelegatorValidatorResponse;
    fromPartial(object: DeepPartial<QueryDelegatorValidatorResponse>): QueryDelegatorValidatorResponse;
};
/**
 * QueryHistoricalInfoRequest is request type for the Query/HistoricalInfo RPC
 * method.
 * @name QueryHistoricalInfoRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryHistoricalInfoRequest
 */
export declare const QueryHistoricalInfoRequest: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryHistoricalInfoRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryHistoricalInfoRequest;
    fromPartial(object: DeepPartial<QueryHistoricalInfoRequest>): QueryHistoricalInfoRequest;
};
/**
 * QueryHistoricalInfoResponse is response type for the Query/HistoricalInfo RPC
 * method.
 * @name QueryHistoricalInfoResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryHistoricalInfoResponse
 */
export declare const QueryHistoricalInfoResponse: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryHistoricalInfoResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryHistoricalInfoResponse;
    fromPartial(object: DeepPartial<QueryHistoricalInfoResponse>): QueryHistoricalInfoResponse;
};
/**
 * QueryPoolRequest is request type for the Query/Pool RPC method.
 * @name QueryPoolRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryPoolRequest
 */
export declare const QueryPoolRequest: {
    typeUrl: string;
    aminoType: string;
    encode(_: QueryPoolRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryPoolRequest;
    fromPartial(_: DeepPartial<QueryPoolRequest>): QueryPoolRequest;
};
/**
 * QueryPoolResponse is response type for the Query/Pool RPC method.
 * @name QueryPoolResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryPoolResponse
 */
export declare const QueryPoolResponse: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryPoolResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryPoolResponse;
    fromPartial(object: DeepPartial<QueryPoolResponse>): QueryPoolResponse;
};
/**
 * QueryParamsRequest is request type for the Query/Params RPC method.
 * @name QueryParamsRequest
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryParamsRequest
 */
export declare const QueryParamsRequest: {
    typeUrl: string;
    aminoType: string;
    encode(_: QueryParamsRequest, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryParamsRequest;
    fromPartial(_: DeepPartial<QueryParamsRequest>): QueryParamsRequest;
};
/**
 * QueryParamsResponse is response type for the Query/Params RPC method.
 * @name QueryParamsResponse
 * @package cosmos.staking.v1beta1
 * @see proto type: cosmos.staking.v1beta1.QueryParamsResponse
 */
export declare const QueryParamsResponse: {
    typeUrl: string;
    aminoType: string;
    encode(message: QueryParamsResponse, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): QueryParamsResponse;
    fromPartial(object: DeepPartial<QueryParamsResponse>): QueryParamsResponse;
};
