"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSendEnabled = exports.getDenomOwnersByQuery = exports.getDenomOwners = exports.getDenomMetadataByQueryString = exports.getDenomMetadata = exports.getDenomsMetadata = exports.getParams = exports.getSupplyOf = exports.getTotalSupply = exports.getSpendableBalanceByDenom = exports.getSpendableBalances = exports.getAllBalances = exports.getBalance = void 0;
const helper_func_types_1 = require("../../../helper-func-types");
const query_1 = require("./query");
/**
 * Balance queries the balance of a single coin for a single account.
 * @name getBalance
 * @package cosmos.bank.v1beta1
 * @see proto service: cosmos.bank.v1beta1.Balance
 */
exports.getBalance = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryBalanceRequest.encode,
    decode: query_1.QueryBalanceResponse.decode,
    service: "cosmos.bank.v1beta1.Query",
    method: "Balance"
});
/**
 * AllBalances queries the balance of all coins for a single account.
 *
 * When called from another module, this query might consume a high amount of
 * gas if the pagination field is incorrectly set.
 * @name getAllBalances
 * @package cosmos.bank.v1beta1
 * @see proto service: cosmos.bank.v1beta1.AllBalances
 */
exports.getAllBalances = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryAllBalancesRequest.encode,
    decode: query_1.QueryAllBalancesResponse.decode,
    service: "cosmos.bank.v1beta1.Query",
    method: "AllBalances"
});
/**
 * SpendableBalances queries the spendable balance of all coins for a single
 * account.
 *
 * When called from another module, this query might consume a high amount of
 * gas if the pagination field is incorrectly set.
 * @name getSpendableBalances
 * @package cosmos.bank.v1beta1
 * @see proto service: cosmos.bank.v1beta1.SpendableBalances
 */
exports.getSpendableBalances = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QuerySpendableBalancesRequest.encode,
    decode: query_1.QuerySpendableBalancesResponse.decode,
    service: "cosmos.bank.v1beta1.Query",
    method: "SpendableBalances"
});
/**
 * SpendableBalanceByDenom queries the spendable balance of a single denom for
 * a single account.
 *
 * When called from another module, this query might consume a high amount of
 * gas if the pagination field is incorrectly set.
 * @name getSpendableBalanceByDenom
 * @package cosmos.bank.v1beta1
 * @see proto service: cosmos.bank.v1beta1.SpendableBalanceByDenom
 */
exports.getSpendableBalanceByDenom = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QuerySpendableBalanceByDenomRequest.encode,
    decode: query_1.QuerySpendableBalanceByDenomResponse.decode,
    service: "cosmos.bank.v1beta1.Query",
    method: "SpendableBalanceByDenom"
});
/**
 * TotalSupply queries the total supply of all coins.
 *
 * When called from another module, this query might consume a high amount of
 * gas if the pagination field is incorrectly set.
 * @name getTotalSupply
 * @package cosmos.bank.v1beta1
 * @see proto service: cosmos.bank.v1beta1.TotalSupply
 */
exports.getTotalSupply = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryTotalSupplyRequest.encode,
    decode: query_1.QueryTotalSupplyResponse.decode,
    service: "cosmos.bank.v1beta1.Query",
    method: "TotalSupply"
});
/**
 * SupplyOf queries the supply of a single coin.
 *
 * When called from another module, this query might consume a high amount of
 * gas if the pagination field is incorrectly set.
 * @name getSupplyOf
 * @package cosmos.bank.v1beta1
 * @see proto service: cosmos.bank.v1beta1.SupplyOf
 */
exports.getSupplyOf = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QuerySupplyOfRequest.encode,
    decode: query_1.QuerySupplyOfResponse.decode,
    service: "cosmos.bank.v1beta1.Query",
    method: "SupplyOf"
});
/**
 * Params queries the parameters of x/bank module.
 * @name getParams
 * @package cosmos.bank.v1beta1
 * @see proto service: cosmos.bank.v1beta1.Params
 */
exports.getParams = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryParamsRequest.encode,
    decode: query_1.QueryParamsResponse.decode,
    service: "cosmos.bank.v1beta1.Query",
    method: "Params"
});
/**
 * DenomsMetadata queries the client metadata for all registered coin
 * denominations.
 * @name getDenomsMetadata
 * @package cosmos.bank.v1beta1
 * @see proto service: cosmos.bank.v1beta1.DenomsMetadata
 */
exports.getDenomsMetadata = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryDenomsMetadataRequest.encode,
    decode: query_1.QueryDenomsMetadataResponse.decode,
    service: "cosmos.bank.v1beta1.Query",
    method: "DenomsMetadata"
});
/**
 * DenomMetadata queries the client metadata of a given coin denomination.
 * @name getDenomMetadata
 * @package cosmos.bank.v1beta1
 * @see proto service: cosmos.bank.v1beta1.DenomMetadata
 */
exports.getDenomMetadata = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryDenomMetadataRequest.encode,
    decode: query_1.QueryDenomMetadataResponse.decode,
    service: "cosmos.bank.v1beta1.Query",
    method: "DenomMetadata"
});
/**
 * DenomMetadataByQueryString queries the client metadata of a given coin denomination.
 * @name getDenomMetadataByQueryString
 * @package cosmos.bank.v1beta1
 * @see proto service: cosmos.bank.v1beta1.DenomMetadataByQueryString
 */
exports.getDenomMetadataByQueryString = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryDenomMetadataByQueryStringRequest.encode,
    decode: query_1.QueryDenomMetadataByQueryStringResponse.decode,
    service: "cosmos.bank.v1beta1.Query",
    method: "DenomMetadataByQueryString"
});
/**
 * DenomOwners queries for all account addresses that own a particular token
 * denomination.
 *
 * When called from another module, this query might consume a high amount of
 * gas if the pagination field is incorrectly set.
 * @name getDenomOwners
 * @package cosmos.bank.v1beta1
 * @see proto service: cosmos.bank.v1beta1.DenomOwners
 */
exports.getDenomOwners = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryDenomOwnersRequest.encode,
    decode: query_1.QueryDenomOwnersResponse.decode,
    service: "cosmos.bank.v1beta1.Query",
    method: "DenomOwners"
});
/**
 * DenomOwnersByQuery queries for all account addresses that own a particular token
 * denomination.
 * @name getDenomOwnersByQuery
 * @package cosmos.bank.v1beta1
 * @see proto service: cosmos.bank.v1beta1.DenomOwnersByQuery
 */
exports.getDenomOwnersByQuery = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryDenomOwnersByQueryRequest.encode,
    decode: query_1.QueryDenomOwnersByQueryResponse.decode,
    service: "cosmos.bank.v1beta1.Query",
    method: "DenomOwnersByQuery"
});
/**
 * SendEnabled queries for SendEnabled entries.
 *
 * This query only returns denominations that have specific SendEnabled settings.
 * Any denomination that does not have a specific setting will use the default
 * params.default_send_enabled, and will not be returned by this query.
 * @name getSendEnabled
 * @package cosmos.bank.v1beta1
 * @see proto service: cosmos.bank.v1beta1.SendEnabled
 */
exports.getSendEnabled = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QuerySendEnabledRequest.encode,
    decode: query_1.QuerySendEnabledResponse.decode,
    service: "cosmos.bank.v1beta1.Query",
    method: "SendEnabled"
});
