"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getParams = exports.getPool = exports.getHistoricalInfo = exports.getDelegatorValidator = exports.getDelegatorValidators = exports.getRedelegations = exports.getDelegatorUnbondingDelegations = exports.getDelegatorDelegations = exports.getUnbondingDelegation = exports.getDelegation = exports.getValidatorUnbondingDelegations = exports.getValidatorDelegations = exports.getValidator = exports.getValidators = void 0;
const helper_func_types_1 = require("../../../helper-func-types");
const query_1 = require("./query");
/**
 * Validators queries all validators that match the given status.
 *
 * When called from another module, this query might consume a high amount of
 * gas if the pagination field is incorrectly set.
 * @name getValidators
 * @package cosmos.staking.v1beta1
 * @see proto service: cosmos.staking.v1beta1.Validators
 */
exports.getValidators = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryValidatorsRequest.encode,
    decode: query_1.QueryValidatorsResponse.decode,
    service: "cosmos.staking.v1beta1.Query",
    method: "Validators"
});
/**
 * Validator queries validator info for given validator address.
 * @name getValidator
 * @package cosmos.staking.v1beta1
 * @see proto service: cosmos.staking.v1beta1.Validator
 */
exports.getValidator = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryValidatorRequest.encode,
    decode: query_1.QueryValidatorResponse.decode,
    service: "cosmos.staking.v1beta1.Query",
    method: "Validator"
});
/**
 * ValidatorDelegations queries delegate info for given validator.
 *
 * When called from another module, this query might consume a high amount of
 * gas if the pagination field is incorrectly set.
 * @name getValidatorDelegations
 * @package cosmos.staking.v1beta1
 * @see proto service: cosmos.staking.v1beta1.ValidatorDelegations
 */
exports.getValidatorDelegations = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryValidatorDelegationsRequest.encode,
    decode: query_1.QueryValidatorDelegationsResponse.decode,
    service: "cosmos.staking.v1beta1.Query",
    method: "ValidatorDelegations"
});
/**
 * ValidatorUnbondingDelegations queries unbonding delegations of a validator.
 *
 * When called from another module, this query might consume a high amount of
 * gas if the pagination field is incorrectly set.
 * @name getValidatorUnbondingDelegations
 * @package cosmos.staking.v1beta1
 * @see proto service: cosmos.staking.v1beta1.ValidatorUnbondingDelegations
 */
exports.getValidatorUnbondingDelegations = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryValidatorUnbondingDelegationsRequest.encode,
    decode: query_1.QueryValidatorUnbondingDelegationsResponse.decode,
    service: "cosmos.staking.v1beta1.Query",
    method: "ValidatorUnbondingDelegations"
});
/**
 * Delegation queries delegate info for given validator delegator pair.
 * @name getDelegation
 * @package cosmos.staking.v1beta1
 * @see proto service: cosmos.staking.v1beta1.Delegation
 */
exports.getDelegation = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryDelegationRequest.encode,
    decode: query_1.QueryDelegationResponse.decode,
    service: "cosmos.staking.v1beta1.Query",
    method: "Delegation"
});
/**
 * UnbondingDelegation queries unbonding info for given validator delegator
 * pair.
 * @name getUnbondingDelegation
 * @package cosmos.staking.v1beta1
 * @see proto service: cosmos.staking.v1beta1.UnbondingDelegation
 */
exports.getUnbondingDelegation = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryUnbondingDelegationRequest.encode,
    decode: query_1.QueryUnbondingDelegationResponse.decode,
    service: "cosmos.staking.v1beta1.Query",
    method: "UnbondingDelegation"
});
/**
 * DelegatorDelegations queries all delegations of a given delegator address.
 *
 * When called from another module, this query might consume a high amount of
 * gas if the pagination field is incorrectly set.
 * @name getDelegatorDelegations
 * @package cosmos.staking.v1beta1
 * @see proto service: cosmos.staking.v1beta1.DelegatorDelegations
 */
exports.getDelegatorDelegations = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryDelegatorDelegationsRequest.encode,
    decode: query_1.QueryDelegatorDelegationsResponse.decode,
    service: "cosmos.staking.v1beta1.Query",
    method: "DelegatorDelegations"
});
/**
 * DelegatorUnbondingDelegations queries all unbonding delegations of a given
 * delegator address.
 *
 * When called from another module, this query might consume a high amount of
 * gas if the pagination field is incorrectly set.
 * @name getDelegatorUnbondingDelegations
 * @package cosmos.staking.v1beta1
 * @see proto service: cosmos.staking.v1beta1.DelegatorUnbondingDelegations
 */
exports.getDelegatorUnbondingDelegations = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryDelegatorUnbondingDelegationsRequest.encode,
    decode: query_1.QueryDelegatorUnbondingDelegationsResponse.decode,
    service: "cosmos.staking.v1beta1.Query",
    method: "DelegatorUnbondingDelegations"
});
/**
 * Redelegations queries redelegations of given address.
 *
 * When called from another module, this query might consume a high amount of
 * gas if the pagination field is incorrectly set.
 * @name getRedelegations
 * @package cosmos.staking.v1beta1
 * @see proto service: cosmos.staking.v1beta1.Redelegations
 */
exports.getRedelegations = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryRedelegationsRequest.encode,
    decode: query_1.QueryRedelegationsResponse.decode,
    service: "cosmos.staking.v1beta1.Query",
    method: "Redelegations"
});
/**
 * DelegatorValidators queries all validators info for given delegator
 * address.
 *
 * When called from another module, this query might consume a high amount of
 * gas if the pagination field is incorrectly set.
 * @name getDelegatorValidators
 * @package cosmos.staking.v1beta1
 * @see proto service: cosmos.staking.v1beta1.DelegatorValidators
 */
exports.getDelegatorValidators = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryDelegatorValidatorsRequest.encode,
    decode: query_1.QueryDelegatorValidatorsResponse.decode,
    service: "cosmos.staking.v1beta1.Query",
    method: "DelegatorValidators"
});
/**
 * DelegatorValidator queries validator info for given delegator validator
 * pair.
 * @name getDelegatorValidator
 * @package cosmos.staking.v1beta1
 * @see proto service: cosmos.staking.v1beta1.DelegatorValidator
 */
exports.getDelegatorValidator = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryDelegatorValidatorRequest.encode,
    decode: query_1.QueryDelegatorValidatorResponse.decode,
    service: "cosmos.staking.v1beta1.Query",
    method: "DelegatorValidator"
});
/**
 * HistoricalInfo queries the historical info for given height.
 * @name getHistoricalInfo
 * @package cosmos.staking.v1beta1
 * @see proto service: cosmos.staking.v1beta1.HistoricalInfo
 */
exports.getHistoricalInfo = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryHistoricalInfoRequest.encode,
    decode: query_1.QueryHistoricalInfoResponse.decode,
    service: "cosmos.staking.v1beta1.Query",
    method: "HistoricalInfo"
});
/**
 * Pool queries the pool info.
 * @name getPool
 * @package cosmos.staking.v1beta1
 * @see proto service: cosmos.staking.v1beta1.Pool
 */
exports.getPool = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryPoolRequest.encode,
    decode: query_1.QueryPoolResponse.decode,
    service: "cosmos.staking.v1beta1.Query",
    method: "Pool"
});
/**
 * Parameters queries the staking parameters.
 * @name getParams
 * @package cosmos.staking.v1beta1
 * @see proto service: cosmos.staking.v1beta1.Params
 */
exports.getParams = (0, helper_func_types_1.buildQuery)({
    encode: query_1.QueryParamsRequest.encode,
    decode: query_1.QueryParamsResponse.decode,
    service: "cosmos.staking.v1beta1.Query",
    method: "Params"
});
