"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EthAccount = void 0;
const auth_1 = require("../../../cosmos/auth/v1beta1/auth");
const binary_1 = require("../../../binary");
function createBaseEthAccount() {
    return {
        baseAccount: undefined,
        codeHash: new Uint8Array()
    };
}
/**
 * EthAccount implements the authtypes.AccountI interface and embeds an
 * authtypes.BaseAccount type. It is compatible with the auth AccountKeeper.
 * @name EthAccount
 * @package injective.types.v1beta1
 * @see proto type: injective.types.v1beta1.EthAccount
 */
exports.EthAccount = {
    typeUrl: "/injective.types.v1beta1.EthAccount",
    encode(message, writer = binary_1.BinaryWriter.create()) {
        if (message.baseAccount !== undefined) {
            auth_1.BaseAccount.encode(message.baseAccount, writer.uint32(10).fork()).ldelim();
        }
        if (message.codeHash.length !== 0) {
            writer.uint32(18).bytes(message.codeHash);
        }
        return writer;
    },
    decode(input, length) {
        const reader = input instanceof binary_1.BinaryReader ? input : new binary_1.BinaryReader(input);
        let end = length === undefined ? reader.len : reader.pos + length;
        const message = createBaseEthAccount();
        while (reader.pos < end) {
            const tag = reader.uint32();
            switch (tag >>> 3) {
                case 1:
                    message.baseAccount = auth_1.BaseAccount.decode(reader, reader.uint32());
                    break;
                case 2:
                    message.codeHash = reader.bytes();
                    break;
                default:
                    reader.skipType(tag & 7);
                    break;
            }
        }
        return message;
    },
    fromPartial(object) {
        const message = createBaseEthAccount();
        message.baseAccount = object.baseAccount !== undefined && object.baseAccount !== null ? auth_1.BaseAccount.fromPartial(object.baseAccount) : undefined;
        message.codeHash = object.codeHash ?? new Uint8Array();
        return message;
    }
};
